@@ -48,6 +48,9 @@ class Settings(object):
         "enable_desktop":       False,
         "desktop_fullscreen":   False,
         "desktop_remember_pos": True,
+        "idle_when_paused":     False,
+        "stop_idle":            False,
+        "transcode_to_h265":    False,
     }
 
     def __getattr__(self, name):
