@@ -345,13 +345,14 @@ class OSDMenu(object):
             ("Subtitle Size: {0}".format(settings.subtitle_size), self.subtitle_size_menu),
             ("Subtitle Position: {0}".format(settings.subtitle_position), self.subtitle_position_menu),
             ("Subtitle Color: {0}".format(self.get_subtitle_color(settings.subtitle_color)), self.subtitle_color_menu),
-            self.get_settings_toggle("Transcode H265", "transcode_h265"),
-            self.get_settings_toggle("Transcode Hi10p", "transcode_hi10p"),
+            self.get_settings_toggle("Transcode H265 to H264", "transcode_h265"),
+            self.get_settings_toggle("Transcode Hi10p to 8bit", "transcode_hi10p"),
             self.get_settings_toggle("Direct Paths", "direct_paths"),
             self.get_settings_toggle("Auto Fullscreen", "fullscreen"),
             self.get_settings_toggle("Media Key Seek", "media_key_seek"),
             self.get_settings_toggle("Use Web Seek Pref", "use_web_seek"),
             self.get_settings_toggle("Display Mirroring", "display_mirroring"),
+            self.get_settings_toggle("Transcode to H265", "transcode_to_h265"),
         ])
 
     def unwatched_menu_handle(self):
